# nbextension-share-button
------------
[![PyPI version](https://badge.fury.io/py/nbextension-share-button.svg)](https://badge.fury.io/py/nbextension-share-button)

A Jupyter Notebook extension that adds a share button to the toolbar.

Screenshots
------------
Button in the toolbar:  
![share-button](share-button.jpg)

Popup with the link:  
![share-popup](share-popup.jpg)


Installation
------------

Install using pip:

    pip install nbextension-share-button

Install extension:

    jupyter nbextension install [--user] --py share_button

Enable extension:

    jupyter nbextension enable [--user] --py share_button
